@@ -150,7 +150,7 @@ class Trafaret(object):
         Appends new converter to list.
         """
         if hasattr(self, 'converters'):
-            self.converters.append(converter)
+            self.checkers.append(converter)
         else:
             self.converters = [converter]
         return self
